 ## 🚀 Dependencies

The following Python packages are used by this project; their licenses are as shown (versions as of May 2025):

 Name                          Version      License                                                                                
 Jinja2                        3.1.6        BSD License                                                                            
 MarkupSafe                    3.0.2        BSD License                                                                            
 MouseInfo                     0.1.3        GNU General Public License v3 or later (GPLv3+)                                        
 PyAudio                       0.2.14       MIT License                                                                            
 PyAutoGUI                     0.9.54       BSD License                                                                            
 PyGetWindow                   0.0.9        BSD License                                                                            
 PyMsgBox                      1.0.9        GNU General Public License v3 or later (GPLv3+)                                        
 PyMuPDF                       1.25.5       Dual Licensed - GNU AFFERO GPL 3.0 or Artifex Commercial License                       
 PyRect                        0.2.0        BSD License                                                                            
 PyScreeze                     1.0.1        MIT License                                                                            
 PyYAML                        6.0.2        MIT License                                                                            
 annotated-types               0.7.0        MIT License                                                                            
 audioread                     3.0.1        UNKNOWN                                                                                
 beautifulsoup4                4.13.4       MIT License                                                                            
 cachetools                    5.5.2        MIT License                                                                            
 certifi                       2025.4.26    Mozilla Public License 2.0 (MPL 2.0)                                                   
 cffi                          1.17.1       MIT License                                                                            
 chardet                       5.2.0        GNU Lesser General Public License v2 or later (LGPLv2+)                                
 charset-normalizer            3.4.2        MIT License                                                                            
 click                         8.1.8        BSD License                                                                            
 colorama                      0.4.6        BSD License                                                                            
 comtypes                      1.4.10       MIT License                                                                            
 cryptography                  44.0.3       Apache Software License; BSD License                                                   
 cssselect                     1.3.0        BSD License                                                                            
 decorator                     5.2.1        BSD License                                                                            
 easyocr                       1.7.2        Apache License 2.0                                                                     
 filelock                      3.18.0       The Unlicense (Unlicense)                                                              
 freeai-utils                  0.2.3        MIT                                                                                    
 fsspec                        2025.3.2     BSD License                                                                            
 gTTS                          2.5.4        MIT License                                                                            
 google-ai-generativelanguage  0.6.15       Apache Software License                                                                
 google-api-core               2.25.0rc1    Apache Software License                                                                
 google-api-python-client      2.169.0      Apache Software License                                                                
 google-auth                   2.40.1       Apache Software License                                                                
 google-auth-httplib2          0.2.0        Apache Software License                                                                
 google-generativeai           0.8.5        Apache Software License                                                                
 googleapis-common-protos      1.70.0       Apache Software License                                                                
 googlesearch-python           1.3.0        MIT License                                                                            
 grpcio                        1.71.0       Apache Software License                                                                
 grpcio-status                 1.71.0       Apache Software License                                                                
 httplib2                      0.22.0       MIT License                                                                            
 huggingface-hub               0.31.2       Apache Software License                                                                
 idna                          3.10         BSD License                                                                            
 imageio                       2.37.0       BSD License                                                                            
 joblib                        1.5.0        BSD License                                                                            
 keyboard                      0.13.5       MIT License                                                                            
 lameenc                       1.8.1        GNU Lesser General Public License v3 (LGPLv3)                                          
 lazy_loader                   0.4          BSD License                                                                            
 librosa                       0.11.0       ISC License (ISCL)                                                                     
 llvmlite                      0.43.0       BSD                                                                                    
 lxml                          5.4.0        BSD License                                                                            
 lxml_html_clean               0.4.2        BSD-3-Clause                                                                           
 more-itertools                10.7.0       MIT License                                                                            
 mpmath                        1.3.0        BSD License                                                                            
 msgpack                       1.1.0        Apache Software License                                                                
 mutagen                       1.47.0       GNU General Public License v2 or later (GPLv2+)                                        
 networkx                      3.2.1        BSD License                                                                            
 ninja                         1.11.1.4     Apache Software License; BSD License                                                   
 numba                         0.60.0       BSD License                                                                            
 numpy                         2.0.2        BSD License                                                                            
 openai-whisper                20240930     MIT                                                                                    
 opencv-python-headless        4.11.0.86    Apache Software License                                                                
 packaging                     25.0         Apache Software License; BSD License                                                   
 pdfminer.six                  20250327     UNKNOWN                                                                                
 pdfplumber                    0.11.6       MIT License                                                                            
 pillow                        11.2.1       UNKNOWN                                                                                
 platformdirs                  4.3.8        MIT License                                                                            
 playsound                     1.2.2        MIT License                                                                            
 pooch                         1.8.2        BSD License                                                                            
 proto-plus                    1.26.1       Apache Software License                                                                
 protobuf                      5.29.4       3-Clause BSD License                                                                   
 pyasn1                        0.6.1        BSD License                                                                            
 pyasn1_modules                0.4.2        BSD License                                                                            
 pyclipper                     1.3.0.post6  MIT License                                                                            
 pycparser                     2.22         BSD License                                                                            
 pydantic                      2.11.4       MIT License                                                                            
 pydantic_core                 2.33.2       MIT License                                                                            
 pyparsing                     3.2.3        MIT License                                                                            
 pypdf                         5.5.0        BSD License                                                                            
 pypdfium2                     4.30.1       BSD-3-Clause, Apache-2.0, PdfiumThirdParty                                             
 pyperclip                     1.9.0        BSD License                                                                            
 pypiwin32                     223          UNKNOWN                                                                                
 python-bidi                   0.6.6        GNU Library or Lesser General Public License (LGPL)                                    
 python-docx                   1.1.2        MIT License                                                                            
 python-dotenv                 1.1.0        BSD License                                                                            
 pyttsx3                       2.98         Mozilla Public License 2.0 (MPL 2.0)                                                   
 pytweening                    1.2.0        MIT License                                                                            
 pywin32                       310          Python Software Foundation License                                                     
 readability-lxml              0.8.4.1      Apache License 2.0                                                                     
 regex                         2024.11.6    Apache Software License                                                                
 requests                      2.32.3       Apache Software License                                                                
 rsa                           4.9.1        Apache Software License                                                                
 safetensors                   0.5.3        Apache Software License                                                                
 scikit-image                  0.24.0       BSD License                                                                            
 scikit-learn                  1.6.1        BSD License                                                                            
 scipy                         1.13.1       BSD License                                                                            
 shapely                       2.0.7        BSD License                                                                            
 six                           1.17.0       MIT License                                                                            
 soundfile                     0.13.1       BSD License                                                                            
 soupsieve                     2.7          MIT License                                                                            
 soxr                          0.5.0.post1  GNU Lesser General Public License v2 or later (LGPLv2+)                                
 sympy                         1.14.0       BSD License                                                                            
 threadpoolctl                 3.6.0        BSD License                                                                            
 tifffile                      2024.8.30    BSD License                                                                            
 tiktoken                      0.9.0        MIT License                                                                            
                                                                                                                                   
                                                    Copyright (c) 2022 OpenAI, Shantanu Jain                                       
                                                                                                                                   
                                                    Permission is hereby granted, free of charge, to any person obtaining a copy   
                                                    of this software and associated documentation files (the "Software"), to deal  
                                                    in the Software without restriction, including without limitation the rights   
                                                    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell      
                                                    copies of the Software, and to permit persons to whom the Software is          
                                                    furnished to do so, subject to the following conditions:                       
                                                                                                                                   
                                                    The above copyright notice and this permission notice shall be included in all 
                                                    copies or substantial portions of the Software.                                
                                                                                                                                   
                                                    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     
                                                    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,       
                                                    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE    
                                                    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER         
                                                    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,  
                                                    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  
                                                    SOFTWARE.                                                                      
                                                                                                                                   
 tokenizers                    0.21.1       Apache Software License                                                                
 torch                         2.7.0        BSD License                                                                            
 torchvision                   0.22.0       BSD                                                                                    
 tqdm                          4.67.1       MIT License; Mozilla Public License 2.0 (MPL 2.0)                                      
 transformers                  4.51.3       Apache Software License                                                                
 typing-inspection             0.4.0        MIT License                                                                            
 typing_extensions             4.13.2       UNKNOWN                                                                                
 uritemplate                   4.1.1        Apache Software License; BSD License                                                   
 urllib3                       2.4.0        UNKNOWN                                                                                

## 📦 Models

| Model ID                                | License |
| --------------------------------------- | ------- |
| openai/whisper-small                    | MIT     |
| namphungdn134/whisper-small-vi (fine-tune) | MIT     |
| openai/whisper-medium                   | MIT     |
| Salesforce/blip-image-captioning-large  |  BSD-3-Clause |
| deepset/tinyroberta-squad2             | cc-by-4.0 |
---

## 📚 Citation

If you use this model in your research or application, please cite:  

```bibtex
@article{Whisper2021,
  title={Whisper: A Multilingual Speech Recognition Model},
  author={OpenAI},
  year={2021},
  journal={arXiv:2202.12064},
  url={https://arxiv.org/abs/2202.12064}
}

@misc{namphung_whisper_small_vi,
  title={Whisper Small Vi V1.1 – Vietnamese Fine-Tuned by Nam Phùng},
  author={Nam Phùng},
  organization={DUT},
  year={2025},
  url={https://huggingface.co/namphungdn134/whisper-small-vi}
}

@misc{https://doi.org/10.48550/arxiv.2201.12086,
  doi = {10.48550/ARXIV.2201.12086},
  url = {https://arxiv.org/abs/2201.12086},
  author = {Li, Junnan and Li, Dongxu and Xiong, Caiming and Hoi, Steven},
  keywords = {Computer Vision and Pattern Recognition (cs.CV), FOS: Computer and information sciences, FOS: Computer and information sciences},
  title = {BLIP: Bootstrapping Language-Image Pre-training for Unified Vision-Language Understanding and Generation},
  publisher = {arXiv},
  year = {2022},
  copyright = {Creative Commons Attribution 4.0 International}
}

@misc{radford2022whisper,
  doi = {10.48550/ARXIV.2212.04356},
  url = {https://arxiv.org/abs/2212.04356},
  author = {Radford, Alec and Kim, Jong Wook and Xu, Tao and Brockman, Greg and McLeavey, Christine and Sutskever, Ilya},
  title = {Robust Speech Recognition via Large-Scale Weak Supervision},
  publisher = {arXiv},
  year = {2022},
  copyright = {arXiv.org perpetual, non-exclusive license}
}

